/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.extension.repository.aether.internal.configuration;

import java.io.File;

import javax.inject.Inject;
import javax.inject.Provider;
import javax.inject.Singleton;

import org.xwiki.component.annotation.Component;
import org.xwiki.configuration.ConfigurationSource;
import org.xwiki.environment.Environment;

/**
 * @version $Id: aad28c2756f3526506a39a7476ebd8af74c454bc $
 * @since 4.0M1
 */
@Component
@Singleton
public class DefaultAetherConfiguration implements AetherConfiguration
{
    @Inject
    private Provider<ConfigurationSource> configurationSourceProvider;

    @Inject
    private Environment environment;

    @Override
    public File getLocalRepository()
    {
        String localRepositoryPath =
            this.configurationSourceProvider.get().getProperty("extension.aether.localRepository");

        File directory;
        if (localRepositoryPath == null) {
            directory = new File(this.environment.getTemporaryDirectory(), "aether-repository");
        } else {
            directory = new File(localRepositoryPath);
        }

        return directory;
    }
}
